#!/usr/bin/env python
# Software License Agreement (BSD License)
#
# Copyright (c) 2008, Willow Garage, Inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
#  * Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#  * Redistributions in binary form must reproduce the above
#    copyright notice, this list of conditions and the following
#    disclaimer in the documentation and/or other materials provided
#    with the distribution.
#  * Neither the name of the Willow Garage nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

##\author Jeremy Leibs

import roslib
roslib.load_manifest('qualification')

from pr2_self_test_msgs.srv import TestResult, TestResultRequest

import rospy 

NAME = 'ping'

import os
import sys
from StringIO import StringIO
import subprocess
from optparse import OptionParser


if __name__ == "__main__":
    rospy.init_node(NAME)
    
    check_eula = True
    
    parser = OptionParser(usage="usage: ping.py [--eula] <ip-addr>")
    parser.add_option("--eula", action="store_true", dest="eula")

    (options,args) = parser.parse_args()

    ip = args[0]

    r = TestResultRequest()
    r.plots = []

    success = False

    for i in xrange(60):
        ret = subprocess.call(['ping','-c','1',ip],stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        if ret == 0:
            success = True
            break
        else:
            if options.eula:
                subprocess.call(['wgeula'],stdout=subprocess.PIPE, stderr=subprocess.PIPE)

    if success:
        r.html_result = "<p>Successfully pinged %s</p>"%ip
        r.result = TestResultRequest.RESULT_PASS
        r.text_summary = "Ping successful"
    else:
        r.html_result = "<p>Failed to ping %s</p>"%ip
        r.result = TestResultRequest.RESULT_FAIL
        r.text_summary = "Ping Failed"
    
    # block until the test_result service is available
    rospy.wait_for_service('test_result')
    result_service = rospy.ServiceProxy('test_result', TestResult)
    result_service.call(r)

    rospy.spin()
